/*
  Copyright 2021 Kakao Corp.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.kakao.sdk.partner.friend.model

import android.os.Parcelable
import com.google.gson.annotations.SerializedName
import com.kakao.sdk.common.json.UnknownValue
import kotlinx.parcelize.Parcelize

/**
 * 선택한 카카오톡 채팅방 정보.
 * @property id 채팅방 ID
 * @property memberCount 채팅방 멤버 수
 * @property titleSource 채팅방 이름 타입
 * @property imageUrl 채팅방 이미지의 URL
 * @property type 선택한 채팅방의 타입
 */
@Parcelize
data class SelectedChat(
    val id: Long,
    val memberCount: Int? = 0,
    val titleSource: String?,
    val imageUrl: String?,
    var type: PickerChatType?
) : Parcelable

/**
 * 채팅방의 종류
 */
enum class PickerChatType {
    /**
     * 일반채팅
     */
    @SerializedName("regular")
    REGULAR,
    /**
     * 오픈채팅
     */
    @SerializedName("open")
    OPEN,
    @UnknownValue
    UNKNOWN;
}