/*
  Copyright 2021 Kakao Corp.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.kakao.sdk.partner.friend.util

import android.content.Context
import android.graphics.Bitmap
import android.graphics.BitmapFactory
import android.util.TypedValue
import com.kakao.sdk.v2.partner.friend.R
import kotlin.math.abs

/**
 * @suppress
 */
internal fun getDefaultProfileImage(id: Int?, context: Context): TypedValue {
    val value = TypedValue()
    when (abs(id?.rem(3) ?: 0)) {
        0 -> context.theme.resolveAttribute(
            R.attr.default_profile_image1,
            value,
            true
        )
        1 -> context.theme.resolveAttribute(
            R.attr.default_profile_image2,
            value,
            true
        )
        2 -> context.theme.resolveAttribute(
            R.attr.default_profile_image3,
            value,
            true
        )
    }
    return value
}

internal fun getDefaultProfileImageBitmap(id: Int?, context: Context): Bitmap {
    return BitmapFactory.decodeResource(
        context.resources,
        getDefaultProfileImage(id.hashCode(), context).resourceId
    )
}

internal fun getDefaultProfileImageBitmap(
    id: Int?,
    context: Context,
    width: Int,
    height: Int
): Bitmap {
    return Bitmap.createScaledBitmap(
        getDefaultProfileImageBitmap(id.hashCode(), context),
        width,
        height,
        true
    )
}